@@ -289,7 +289,7 @@ register int errno;
 _dld_malloc (size)
 int size;
 {
-    register int result = malloc (size);
+    register int result = (int) malloc (size);
     if (!result)
 	fatal (DLD_ENOMEMORY);
     return result;
@@ -672,7 +672,7 @@ char *name;
 	    sp->defined = type;
 	    sp->value = common ? (long) _dld_malloc (nlist_p->n_value) :
 		nlist_p->n_value;
-	    if (common) bzero (sp->value, nlist_p->n_value);
+	    if (common) bzero ((void *)sp->value, nlist_p->n_value);
 	    sp->defined_by = entry;
 	}
 
@@ -811,7 +811,7 @@ cleanup_symtab ()
 #else
 		if (sp->defined == (N_TYPE | N_EXT) && sp->value)
 #endif
-		    free (sp->value);
+		    free ((void *)sp->value);
 		if (sp->referenced_by == 0) {
 		    free (sp->name);
 		    del_link_list_elt (_dld_symtab[i], prev_sp, sp, link);
@@ -832,7 +832,7 @@ cleanup_symtab ()
 #else
 		if (sp->defined == (N_TYPE | N_EXT) && sp->value)
 #endif
-		    free (sp->value);
+		    free ((void *)sp->value);
 		del_link_list_elt (_dld_symtab[i], prev_sp, sp, link);
 		continue;
 	    }
@@ -1655,7 +1655,7 @@ register struct file_entry *entry;
     lseek (desc, entry->starting_offset + N_TXTOFF(entry->header), 0);
     size -= entry->header.a_bss;
     if (size != read (desc, entry->text_start_address, size)) {
-	free (entry->text_start_address);
+	free ((void *)entry->text_start_address);
 	entry->text_start_address = entry->data_start_address =
 	    entry->bss_start_address = 0;
 	fatal (DLD_ENODATA);
@@ -1735,8 +1735,7 @@ register struct file_entry *entry;
  * reset the executable_flag of the given entry, and then recursively
  * propagate this to all modules that reference symbols in this entry.
  */
-static void
-invalidate (entry)
+static void Invalidate (entry)
 struct file_entry *entry;
 {
     register struct file_chain *p;
@@ -1748,7 +1747,7 @@ struct file_entry *entry;
 
     for (p = entry->refs_by; p; p = p->next)
 	if (p->entry->executable_flag)
-	    invalidate (p->entry);
+	    Invalidate (p->entry);
 } /* invalidate */
 
 /*
@@ -1778,11 +1777,11 @@ find_all_executable_modules ()
 	    register struct file_entry *q = p->subfiles;
 	    while (q) {
 		if (!q->all_symbols_resolved_flag && q->refs_by)
-		    invalidate (q);
+		    Invalidate (q);
 		q = q->chain;
 	    }
 	} else if (!p->all_symbols_resolved_flag && p->refs_by)
-	    invalidate (p);
+	    Invalidate (p);
     }
     _dld_exec_flags_valid = 1;
 } /* find_all_executable_modules */
@@ -1893,7 +1892,7 @@ register struct file_entry *entry;
 
     if (entry->data_reloc) free (entry->data_reloc);
 
-    if (entry->text_start_address) free (entry->text_start_address);
+    if (entry->text_start_address) free ((void *)entry->text_start_address);
 
     {
 	register struct file_entry *next = entry->chain;
